document.addEventListener('DOMContentLoaded', () => {
  const consultForm = document.getElementById('consultForm');
  const reviewForm = document.getElementById('reviewForm');
  const reviewsContainer = document.getElementById('reviewsContainer');
  const imageInput = document.getElementById('images');
  const imagePreview = document.getElementById('imagePreview');

  // Handle image preview
  imageInput.addEventListener('change', (e) => {
    imagePreview.innerHTML = '';
    const files = Array.from(e.target.files);
    
    files.forEach(file => {
      if (file.type.startsWith('image/')) {
        const reader = new FileReader();
        reader.onload = (e) => {
          const img = document.createElement('img');
          img.src = e.target.result;
          imagePreview.appendChild(img);
        };
        reader.readAsDataURL(file);
      }
    });
  });

  // Handle consultation form submission
  consultForm.addEventListener('submit', (e) => {
    e.preventDefault();
    const formData = new FormData(consultForm);
    // Here you would typically send the data to a server
    alert('Consultation submitted successfully!');
    consultForm.reset();
    imagePreview.innerHTML = '';
  });

  // Handle review form submission
  reviewForm.addEventListener('submit', (e) => {
    e.preventDefault();
    const name = document.getElementById('reviewName').value;
    const text = document.getElementById('reviewText').value;
    
    addReview(name, text);
    reviewForm.reset();
  });

  // Add a new review to the page
  function addReview(name, text) {
    const review = document.createElement('div');
    review.className = 'review';
    review.innerHTML = `
      <strong>${name}</strong>
      <p>${text}</p>
      <small>${new Date().toLocaleDateString()}</small>
    `;
    reviewsContainer.prepend(review);
  }

  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });
});
